#!/bin/bash

#MAINTNER="Anonymous Coward <nobody@mydomain.com>"
MAINTNER="Frank Rysanek <rysanek@fccps.cz>"

my_exit () {
	echo "Please specify kernel version and arch."
	echo ""
	echo "usage: $0 <kernel_version_string> <CPU_arch>"
	echo "example: $0 4.14.10 amd64"
	echo ""
	echo "purpose: to prepare your own kernel .deb package"
	echo " that you can use on other machines."
	echo " A light-weight alternative to the 1.5GB mammoth called kernel-package."
	echo ""
	echo "On the build machine, you should've run "
	echo "   make install"
	echo "and"
	echo "   make modules_install"
	echo "ahead of $0 ,"
	echo "as $0 only slurps the ready kernel and modules"
	echo "from the build machine."
	echo "Feel free to modify some package control variables in the $0 script."
	echo ""
	echo "Note:"
	echo " The kernel version is expected as a precise suffix on the various"
	echo " binaries under /boot and /lib/modules/kernel_version/."
	echo " The CPU_arch will appear on package name and in package descr,"
	echo " but is NOT EXPECTED on /boot/vmlinuz, /lib/modules/kern-ver etc. !"
	echo ""
	exit 1
}

echo "Kernel tarball packager."
echo ""

[ "$1" = "" ] && my_exit
[ "$2" = "" ] && my_exit

KERN_VER=$1
CPU_ARCH=$2
DEB_NAME="linux-image-$KERN_VER-1-$CPU_ARCH"

#TAR_CMD="tar cvzf debian_kernel_$1.tgz /boot/config-$1 /boot/initrd.img-$1 /boot/System.map-$1 /boot/vmlinuz-$1 /lib/modules/$1"

echo "making ./$DEB_NAME and subdirs"

mkdir $DEB_NAME
mkdir $DEB_NAME/DEBIAN
mkdir $DEB_NAME/boot
mkdir $DEB_NAME/lib
mkdir $DEB_NAME/lib/modules

echo "copying files from /boot"

cp -dpR /boot/config-$KERN_VER \
	/boot/System.map-$KERN_VER \
	/boot/vmlinuz-$KERN_VER \
	$DEB_NAME/boot/

echo "copying /lib/modules/$KERN_VER . This can take a couple dozen seconds."

cp -dpR /lib/modules/$KERN_VER \
	$DEB_NAME/lib/modules/

echo "creating package control files under $DEB_NAME/DEBIAN/"

echo "Package: $DEB_NAME" > $DEB_NAME/DEBIAN/control
echo "Version: $KERN_VER-1" >> $DEB_NAME/DEBIAN/control
echo "Section: kernel" >> $DEB_NAME/DEBIAN/control
echo "Priority: optional" >> $DEB_NAME/DEBIAN/control
echo "Maintainer: $MAINTNER" >> $DEB_NAME/DEBIAN/control
echo "Standards-Version: 4.0.0" >> $DEB_NAME/DEBIAN/control
echo "Homepage: https://www.kernel.org" >> $DEB_NAME/DEBIAN/control
echo "Architecture: $CPU_ARCH" >> $DEB_NAME/DEBIAN/control
echo "Depends: initramfs-tools" >> $DEB_NAME/DEBIAN/control
echo "Description: Custom pre-built Linux kernel" >> $DEB_NAME/DEBIAN/control

echo "#!/bin/sh" > $DEB_NAME/DEBIAN/postinst
echo "if [ -f \"/boot/initrd.img-$KERN_VER\" ]; then" >> $DEB_NAME/DEBIAN/postinst
echo "	update-initramfs -u -k $KERN_VER" >> $DEB_NAME/DEBIAN/postinst
echo "	echo \"update-grub or equivalent probably not needed.\"" >> $DEB_NAME/DEBIAN/postinst
echo "else" >> $DEB_NAME/DEBIAN/postinst
echo "	update-initramfs -c -k $KERN_VER" >> $DEB_NAME/DEBIAN/postinst
echo "	echo \"Remember to run update-grub or equivalent!\"" >> $DEB_NAME/DEBIAN/postinst
echo "fi" >> $DEB_NAME/DEBIAN/postinst
chmod 755 $DEB_NAME/DEBIAN/postinst

echo "running dpkg-deb. This can take a couple dozen seconds."

dpkg-deb --build $DEB_NAME 

echo "$0 done. Feel free to   rm -Rf $DEB_NAME   yourselfs."
